from .resolve_path import resolve_path

bee = resolve_path('images/enemies/bee.png')
fish_green = resolve_path('images/enemies/fishGreen.png')
fish_pink = resolve_path('images/enemies/fishPink.png')
fly = resolve_path('images/enemies/fly.png')
frog = resolve_path('images/enemies/frog.png')
frog_move = resolve_path('images/enemies/frog_move.png')
ladybug = resolve_path('images/enemies/ladybug.png')
mouse = resolve_path('images/enemies/mouse.png')
saw = resolve_path('images/enemies/saw.png')
saw_half = resolve_path('images/enemies/sawHalf.png')
slime_block = resolve_path('images/enemies/slimeBlock.png')
slime_blue = resolve_path('images/enemies/slimeBlue.png')
slime_blue_move = resolve_path('images/enemies/slimeBlue_move.png')
slime_green = resolve_path('images/enemies/slimeGreen.png')
slime_purple = resolve_path('images/enemies/slimePurple.png')
worm_green = resolve_path('images/enemies/wormGreen.png')
worm_green_dead = resolve_path('images/enemies/wormGreen_dead.png')
worm_green_move = resolve_path('images/enemies/wormGreen_move.png')
worm_pink = resolve_path('images/enemies/wormPink.png')
coin_bronze = resolve_path('images/items/coinBronze.png')
coin_gold = resolve_path('images/items/gold_1.png')
coin_gold_ll = resolve_path('images/items/coinGold_ll.png')
coin_gold_lr = resolve_path('images/items/coinGold_lr.png')
coin_gold_ul = resolve_path('images/items/coinGold_ul.png')
coin_gold_ur = resolve_path('images/items/coinGold_ur.png')
coin_silver = resolve_path('images/items/coinSilver_test.png')
coin_silver_test = resolve_path('images/items/coinSilver_test.png')
flag_green1 = resolve_path('images/items/flagGreen1.png')
flag_green2 = resolve_path('images/items/flagGreen2.png')
flag_green_down = resolve_path('images/items/flagGreen_down.png')
flag_red1 = resolve_path('images/items/flagRed1.png')
flag_red2 = resolve_path('images/items/flagRed2.png')
flag_red_down = resolve_path('images/items/flagRed_down.png')
flag_yellow1 = resolve_path('images/items/flagYellow1.png')
flag_yellow2 = resolve_path('images/items/flagYellow2.png')
flag_yellow_down = resolve_path('images/items/flagYellow_down.png')
gem_blue = resolve_path('images/items/gemBlue.png')
gem_green = resolve_path('images/items/gemGreen.png')
gem_red = resolve_path('images/items/gemRed.png')
gem_yellow = resolve_path('images/items/gemYellow.png')
gold_1 = resolve_path('images/items/gold_1.png')
gold_2 = resolve_path('images/items/gold_2.png')
gold_3 = resolve_path('images/items/gold_3.png')
gold_4 = resolve_path('images/items/gold_4.png')
key_blue = resolve_path('images/items/keyBlue.png')
key_green = resolve_path('images/items/keyGreen.png')
key_red = resolve_path('images/items/keyRed.png')
key_yellow = resolve_path('images/items/keyYellow.png')
ladder_mid = resolve_path('images/items/ladderMid.png')
ladder_top = resolve_path('images/items/ladderTop.png')
star = resolve_path('images/items/star.png')
laser_blue01 = resolve_path('images/space_shooter/laserBlue01.png')
laser_red01 = resolve_path('images/space_shooter/laserRed01.png')
meteor_grey_big1 = resolve_path('images/space_shooter/meteorGrey_big1.png')
meteor_grey_big2 = resolve_path('images/space_shooter/meteorGrey_big2.png')
meteor_grey_big3 = resolve_path('images/space_shooter/meteorGrey_big3.png')
meteor_grey_big4 = resolve_path('images/space_shooter/meteorGrey_big4.png')
meteor_grey_med1 = resolve_path('images/space_shooter/meteorGrey_med1.png')
meteor_grey_med2 = resolve_path('images/space_shooter/meteorGrey_med2.png')
meteor_grey_small1 = resolve_path('images/space_shooter/meteorGrey_small1.png')
meteor_grey_small2 = resolve_path('images/space_shooter/meteorGrey_small2.png')
meteor_grey_tiny1 = resolve_path('images/space_shooter/meteorGrey_tiny1.png')
meteor_grey_tiny2 = resolve_path('images/space_shooter/meteorGrey_tiny2.png')
player_life1_orange = resolve_path('images/space_shooter/playerLife1_orange.png')
player_ship1_green = resolve_path('images/space_shooter/playerShip1_green.png')
player_ship1_orange = resolve_path('images/space_shooter/playerShip1_orange.png')
player_ship2_orange = resolve_path('images/space_shooter/playerShip2_orange.png')
player_ship3_orange = resolve_path('images/space_shooter/playerShip3_orange.png')

